Pelt
============================================

.. currentmodule:: skchange.change_detectors

.. autoclass:: Pelt

.. include:: skchange.change_detectors.Pelt.examples

.. raw:: html

    <div class="clearer"></div>